@@ -1,11 +1,9 @@
 from abc import abstractmethod
 import requests
-from office365.runtime.http.request_options import RequestOptions
 from requests import HTTPError
 from office365.runtime.client_request_exception import ClientRequestException
 from office365.runtime.http.http_method import HttpMethod
-from office365.runtime.utilities.EventHandler import EventHandler
-from office365.runtime.client_query import ClientQuery
+from office365.runtime.types.EventHandler import EventHandler
 
 
 class ClientRequest(object):
