@@ -1,7 +1,7 @@
-from office365.runtime.client_value_object import ClientValueObject
+from office365.runtime.clientValue import ClientValue
 
 
-class GroupSiteInfo(ClientValueObject):
+class GroupSiteInfo(ClientValue):
 
     def __init__(self):
         super(GroupSiteInfo, self).__init__()
@@ -10,4 +10,3 @@ class GroupSiteInfo(ClientValueObject):
         self.DocumentsUrl = None
         self.ErrorMessage = None
         self.GroupId = None
-
